@@ -28,6 +28,13 @@ import types
 
 PY3 = sys.version_info[0] == 3
 
+try:
+    from statistics import mean
+except ImportError:
+    # Statistics is only available for Python 3.4 or higher
+    def mean(numbers):
+        return float(sum(numbers)) / max(len(numbers), 1)
+
 if PY3:
     import queue
     from configparser import ConfigParser, NoOptionError, NoSectionError
@@ -35,6 +42,7 @@ if PY3:
     from xmlrpc.server import SimpleXMLRPCRequestHandler, SimpleXMLRPCServer
     from urllib.request import urlopen
     from urllib.error import HTTPError, URLError
+    from urllib.parse import urlparse
 
     input = input
     range = range
@@ -90,6 +98,7 @@ else:
     from SimpleXMLRPCServer import SimpleXMLRPCRequestHandler, SimpleXMLRPCServer
     from xmlrpclib import Fault, ProtocolError, ServerProxy, Transport, Server
     from urllib2 import urlopen, HTTPError, URLError
+    from urlparse import urlparse
 
     input = raw_input
     range = xrange
