@@ -49,35 +49,34 @@ class GlancesMain(object):
     username = "glances"
     password = ""
 
-    # Exemple of use
-    example_of_use = "\
-Examples of use:\n\
-\n\
-Monitor local machine (standalone mode):\n\
-  $ glances\n\
-\n\
-Monitor local machine with the Web interface (Web UI):\n\
-  $ glances -w\n\
-  Glances web server started on http://0.0.0.0:61208/\n\
-\n\
-Monitor local machine and export stats to a CSV file (standalone mode):\n\
-  $ glances --export-csv /tmp/glances.csv\n\
-\n\
-Monitor local machine and export stats to a InfluxDB server with 5s refresh time (standalone mode):\n\
-  $ glances -t 5 --export-influxdb\n\
-\n\
-Start a Glances server (server mode):\n\
-  $ glances -s\n\
-\n\
-Connect Glances to a Glances server (client mode):\n\
-  $ glances -c <ip_server>\n\
-\n\
-Connect Glances to a Glances server and export stats to a StatsD server (client mode):\n\
-  $ glances -c <ip_server> --export-statsd\n\
-\n\
-Start the client browser (browser mode):\n\
-  $ glances --browser\n\
-    "
+    # Examples of use
+    example_of_use = """
+Examples of use:
+  Monitor local machine (standalone mode):
+    $ glances
+
+  Monitor local machine with the Web interface (Web UI):
+    $ glances -w
+    Glances web server started on http://0.0.0.0:61208/
+
+  Monitor local machine and export stats to a CSV file (standalone mode):
+    $ glances --export-csv /tmp/glances.csv
+
+  Monitor local machine and export stats to a InfluxDB server with 5s refresh time (standalone mode):
+    $ glances -t 5 --export-influxdb
+
+  Start a Glances server (server mode):
+    $ glances -s
+
+  Connect Glances to a Glances server (client mode):
+    $ glances -c <ip_server>
+
+  Connect Glances to a Glances server and export stats to a StatsD server (client mode):
+    $ glances -c <ip_server> --export-statsd
+
+  Start the client browser (browser mode):
+    $ glances --browser
+"""
 
     def __init__(self):
         """Manage the command line arguments."""
@@ -103,6 +102,8 @@ Start the client browser (browser mode):\n\
                             dest='disable_alert', help='disable alert module')
         parser.add_argument('--disable-amps', action='store_true', default=False,
                             dest='disable_amps', help='disable applications monitoring process (AMP) module')
+        parser.add_argument('--disable-cloud', action='store_true', default=False,
+                            dest='disable_cloud', help='disable Cloud module')
         parser.add_argument('--disable-cpu', action='store_true', default=False,
                             dest='disable_cpu', help='disable CPU module')
         parser.add_argument('--disable-diskio', action='store_true', default=False,
@@ -172,22 +173,26 @@ Start the client browser (browser mode):\n\
                             dest='path_graph', help='set the export path for graphs (default is {})'.format(tempfile.gettempdir()))
         parser.add_argument('--export-csv', default=None,
                             dest='export_csv', help='export stats to a CSV file')
-        parser.add_argument('--export-influxdb', action='store_true', default=False,
-                            dest='export_influxdb', help='export stats to an InfluxDB server (influxdb lib needed)')
         parser.add_argument('--export-cassandra', action='store_true', default=False,
                             dest='export_cassandra', help='export stats to a Cassandra or Scylla server (cassandra lib needed)')
-        parser.add_argument('--export-opentsdb', action='store_true', default=False,
-                            dest='export_opentsdb', help='export stats to an OpenTSDB server (potsdb lib needed)')
-        parser.add_argument('--export-statsd', action='store_true', default=False,
-                            dest='export_statsd', help='export stats to a StatsD server (statsd lib needed)')
+        parser.add_argument('--export-couchdb', action='store_true', default=False,
+                            dest='export_couchdb', help='export stats to a CouchDB server (couch lib needed)')
         parser.add_argument('--export-elasticsearch', action='store_true', default=False,
                             dest='export_elasticsearch', help='export stats to an ElasticSearch server (elasticsearch lib needed)')
+        parser.add_argument('--export-influxdb', action='store_true', default=False,
+                            dest='export_influxdb', help='export stats to an InfluxDB server (influxdb lib needed)')
+        parser.add_argument('--export-kafka', action='store_true', default=False,
+                            dest='export_kafka', help='export stats to a Kafka server (kafka-python lib needed)')
+        parser.add_argument('--export-opentsdb', action='store_true', default=False,
+                            dest='export_opentsdb', help='export stats to an OpenTSDB server (potsdb lib needed)')
+        parser.add_argument('--export-prometheus', action='store_true', default=False,
+                            dest='export_prometheus', help='export stats to a Prometheus exporter (prometheus_client lib needed)')
         parser.add_argument('--export-rabbitmq', action='store_true', default=False,
                             dest='export_rabbitmq', help='export stats to rabbitmq broker (pika lib needed)')
         parser.add_argument('--export-riemann', action='store_true', default=False,
                             dest='export_riemann', help='export stats to riemann broker (bernhard lib needed)')
-        parser.add_argument('--export-couchdb', action='store_true', default=False,
-                            dest='export_couchdb', help='export stats to a CouchDB server (couch lib needed)')
+        parser.add_argument('--export-statsd', action='store_true', default=False,
+                            dest='export_statsd', help='export stats to a StatsD server (statsd lib needed)')
         parser.add_argument('--export-zeromq', action='store_true', default=False,
                             dest='export_zeromq', help='export stats to a ZeroMQ server (pyzmq lib needed)')
         # Client/Server option
@@ -275,11 +280,18 @@ Start the client browser (browser mode):\n\
                 args.port = self.web_server_port
             else:
                 args.port = self.server_port
+        # Port in the -c URI #996
+        if args.client is not None:
+            args.client, args.port = (x if x else y for (x, y) in zip(args.client.partition(':')[::2], (args.client, args.port)))
 
         # Autodiscover
         if args.disable_autodiscover:
             logger.info("Auto discover mode is disabled")
 
+        # By default Windows is started in Web mode
+        if WINDOWS:
+            args.webserver = True
+
         # In web server mode
         if args.webserver:
             args.process_short_name = True
@@ -355,17 +367,15 @@ Start the client browser (browser mode):\n\
         self.args = args
 
         # Export is only available in standalone or client mode (issue #614)
-        export_tag = args.export_csv or \
-            args.export_elasticsearch or \
-            args.export_statsd or \
-            args.export_influxdb or \
-            args.export_cassandra or \
-            args.export_opentsdb or \
-            args.export_rabbitmq or \
-            args.export_couchdb
-        if not (self.is_standalone() or self.is_client()) and export_tag:
-            logger.critical(
-                "Export is only available in standalone or client mode")
+        export_tag = any([getattr(args, a) for a in args.__dict__ if a.startswith('export_')])
+        if WINDOWS and export_tag:
+            # On Windows, export is possible but only in quiet mode
+            # See issue #1038
+            logger.info("On Windows OS, export disable the Web interface")
+            self.args.quiet = True
+            self.args.webserver = False
+        elif not (self.is_standalone() or self.is_client()) and export_tag:
+            logger.critical("Export is only available in standalone or client mode")
             sys.exit(2)
 
         # Filter is only available in standalone mode
@@ -377,8 +387,7 @@ Start the client browser (browser mode):\n\
         # Check graph output path
         if args.export_graph and args.path_graph is not None:
             if not os.access(args.path_graph, os.W_OK):
-                logger.critical(
-                    "Graphs output path {} doesn't exist or is not writable".format(args.path_graph))
+                logger.critical("Graphs output path {} doesn't exist or is not writable".format(args.path_graph))
                 sys.exit(2)
             logger.debug(
                 "Graphs output path is set to {}".format(args.path_graph))
@@ -395,24 +404,12 @@ Start the client browser (browser mode):\n\
 
         return args
 
-    def __get_username(self, description=''):
-        """Read a username from the command line.
-        """
-        return input(description)
-
-    def __get_password(self, description='', confirm=False, clear=False, username='glances'):
-        """Read a password from the command line.
-
-        - if confirm = True, with confirmation
-        - if clear = True, plain (clear password)
-        """
-        from glances.password import GlancesPassword
-        password = GlancesPassword(username=username)
-        return password.get_password(description, confirm, clear)
-
     def is_standalone(self):
         """Return True if Glances is running in standalone mode."""
-        return not self.args.client and not self.args.browser and not self.args.server and not self.args.webserver
+        return (not self.args.client and
+                not self.args.browser and
+                not self.args.server and
+                not self.args.webserver)
 
     def is_client(self):
         """Return True if Glances is running in client mode."""
@@ -437,3 +434,22 @@ Start the client browser (browser mode):\n\
     def get_args(self):
         """Return the arguments."""
         return self.args
+
+    def get_mode(self):
+        """Return the mode."""
+        return self.mode
+
+    def __get_username(self, description=''):
+        """Read an username from the command line.
+        """
+        return input(description)
+
+    def __get_password(self, description='', confirm=False, clear=False, username='glances'):
+        """Read a password from the command line.
+
+        - if confirm = True, with confirmation
+        - if clear = True, plain (clear password)
+        """
+        from glances.password import GlancesPassword
+        password = GlancesPassword(username=username)
+        return password.get_password(description, confirm, clear)
